<?php

 

class appComfinoBackendActions extends autoAppComfinoBackendActions
{
    public function executeConfig()
    {
        $result = parent::executeConfig();

        if ($this->config->get('enabled'))
        {
            try
            {
                appComfinoApi::create($this->config->get('api_key'), $this->config->get('sandbox'))->getFinancialProducts(1000);
            }
            catch (appComfinoApiException $e)
            {
                $this->processApiException($e);
            }
        }

        return $result;
    }

    public function validateConfig()
    {
        stAuthUsersListener::checkModificationCredentials($this, $this->getRequest(), $this->getModuleName());

        $request = $this->getRequest();

        if ($request->getMethod() == sfRequest::POST)
        {
            $i18n = $this->getContext()->getI18N();

            $data = $this->getRequestParameter('config');

            if (!$data['enabled'])
            {
                return true;
            }

            if (empty($data['api_key']))
            {
                $request->setError('config{api_key}', $i18n->__('Uzupełnij pole'));
            }

            if (!$request->hasErrors())
            {
                $api = appComfinoApi::create($data['api_key'], isset($data['sandbox']));

                try
                {
                    $api->testConnection();
                }
                catch(appComfinoApiException $e)
                {
                    $this->processApiException($e);
                }
            }

        }
        
        return !$request->hasErrors();
    }  
    
    protected function saveConfig()
    {
        $this->config->set('has_valid_configuration', true);

        parent::saveConfig();

        if ($this->config->get('enabled'))
        {
            stPaymentTypeConfiguration::get(appComfinoPaymentType::class)->enable();
        }
        else
        {
            stPaymentTypeConfiguration::get(appComfinoPaymentType::class)->disable();
        }

        stFastCacheManager::clearCache();
    }
    
    protected function getConfigLabels()
    {
        $labels = parent::getConfigLabels();

        $labels['api'] = 'Comfino API';

        return $labels;
    }

    protected function processApiException(appComfinoApiException $e)
    {
        $i18n = $this->getContext()->getI18N();
        $request = $this->getRequest();
        $error = $i18n->__($e->getMessage());

        if ($e->getCode() == 401)
        {
            $request->setError('api', $i18n->__('Wystapił problem podczas autoryzacji sprawdź czy wprowadzone dane są prawidłowe'));
        }
        else
        {
            $request->setError('api', $i18n->__('Wystąpił problem z połączeniem (Zwrócony błąd: %error%)', array(
                '%error%' => $error
            )));
        }
    }
}